@@ -34,19 +34,19 @@
     <name>String::WeatherType</name>
     <message>
         <source>Cloudy</source>
-        <translation>Bewölkt</translation>
+        <translation>bewölkt</translation>
     </message>
     <message>
         <source>Mostly Cloudy</source>
-        <translation>Meist bewölkt</translation>
+        <translation>meist bewölkt</translation>
     </message>
     <message>
         <source>Partly Cloudy</source>
-        <translation>Teilweise bewölkt</translation>
+        <translation>teilw. bewölkt</translation>
     </message>
     <message>
         <source>Light Rain</source>
-        <translation>Leichter Regen</translation>
+        <translation>etwas Regen</translation>
     </message>
     <message>
         <source>Showers</source>
@@ -66,15 +66,15 @@
     </message>
     <message>
         <source>Few Showers</source>
-        <translation>Vereinzelte Schauer</translation>
+        <translation>vereinzelte Schauer</translation>
     </message>
     <message>
         <source>Mostly Sunny</source>
-        <translation>Meist sonnig</translation>
+        <translation>meist sonnig</translation>
     </message>
     <message>
         <source>Sunny</source>
-        <translation>Sonnig</translation>
+        <translation>sonnig</translation>
     </message>
     <message>
         <source>Scattered Flurries</source>
@@ -86,39 +86,39 @@
     </message>
     <message>
         <source>Isolated T-Storms</source>
-        <translation>Vereinzelte Gewitter</translation>
+        <translation>vereinzelte Gewitter</translation>
     </message>
     <message>
         <source>Scattered Thunderstorms</source>
-        <translation>Verteilte Gewitter</translation>
+        <translation>verteilte Gewitter</translation>
     </message>
     <message>
         <source>PM Showers</source>
-        <translation>Nachm. Regen</translation>
+        <translation>Nachm. Schauer</translation>
     </message>
     <message>
         <source>PM Showers/Wind</source>
-        <translation>Nachm. Regen/Wind</translation>
+        <translation>Nachm. Schauer/Wind</translation>
     </message>
     <message>
         <source>Rain/Snow Showers</source>
-        <translation>Regen/Schneeregen</translation>
+        <translation>Regen/Schneeschauer</translation>
     </message>
     <message>
         <source>Few Snow Showers</source>
-        <translation>Vereinzelter Schneeregen</translation>
+        <translation>vereinzelte Schneeschauer</translation>
     </message>
     <message>
         <source>Cloudy/Wind</source>
-        <translation>Wolkig/Windig</translation>
+        <translation>bewölkt/windig</translation>
     </message>
     <message>
         <source>Flurries/Wind</source>
-        <translation>Böeig/Windig</translation>
+        <translation>böeig/windig</translation>
     </message>
     <message>
         <source>Mostly Cloudy/Windy</source>
-        <translation>Meist wolkig/Windig</translation>
+        <translation>meist bewölkt/windig</translation>
     </message>
     <message>
         <source>Rain/Thunder</source>
@@ -126,7 +126,7 @@
     </message>
     <message>
         <source>Partly Cloudy/Windy</source>
-        <translation>Teilweise bewölkt/Windig</translation>
+        <translation>teilw. bewölkt/windig</translation>
     </message>
     <message>
         <source>AM Rain/Snow Showers</source>
@@ -134,7 +134,7 @@
     </message>
     <message>
         <source>Light Rain/Wind</source>
-        <translation>Leichter Regen/Wind</translation>
+        <translation>leichter Regen/Wind</translation>
     </message>
     <message>
         <source>Showers/Wind</source>
@@ -142,7 +142,7 @@
     </message>
     <message>
         <source>Mostly Sunny/Wind</source>
-        <translation>Meist sonnig/Wind</translation>
+        <translation>meist sonnig/Wind</translation>
     </message>
     <message>
         <source>Flurries</source>
@@ -154,11 +154,11 @@
     </message>
     <message>
         <source>Sct Flurries/Wind</source>
-        <translation>Verteilt böeige Winde</translation>
+        <translation>verteilte, böeige Winde</translation>
     </message>
     <message>
         <source>Sct Strong Storms</source>
-        <translation>Verteilte starke Stürme</translation>
+        <translation>verteilte, heftige Stürme</translation>
     </message>
     <message>
         <source>PM T-Storms</source>
@@ -170,7 +170,7 @@
     </message>
     <message>
         <source>Sunny/Windy</source>
-        <translation>Sonnig/Windig</translation>
+        <translation>sonnig/windig</translation>
     </message>
     <message>
         <source>AM Thunderstorms</source>
@@ -182,7 +182,7 @@
     </message>
     <message>
         <source>Iso T-Storms/Wind</source>
-        <translation>Vereinzelte Gewitter/Wind</translation>
+        <translation>vereinzelte Gewitter/Wind</translation>
     </message>
     <message>
         <source>Rain/Snow</source>
@@ -190,15 +190,15 @@
     </message>
     <message>
         <source>Sct T-Storms/Wind</source>
-        <translation>Verteilte Gewitter/Wind</translation>
+        <translation>verteilte Gewitter/Wind</translation>
     </message>
     <message>
         <source>AM Showers/Wind</source>
-        <translation>Vorm. Regen/Wind</translation>
+        <translation>Vorm. Schauer/Wind</translation>
     </message>
     <message>
         <source>Sct Snow Showers</source>
-        <translation>Verteilte Schneeschauer</translation>
+        <translation>verteilte Schneeschauer</translation>
     </message>
     <message>
         <source>Snow to Ice/Wind</source>
@@ -210,11 +210,11 @@
     </message>
     <message>
         <source>AM Light Rain</source>
-        <translation>Vorm. leichter Regen</translation>
+        <translation>Vorm. etwas Regen</translation>
     </message>
     <message>
         <source>PM Light Rain</source>
-        <translation>Nachm. leichter Regen</translation>
+        <translation>Nachm. etwas Regen</translation>
     </message>
     <message>
         <source>PM Rain</source>
@@ -234,7 +234,7 @@
     </message>
     <message>
         <source>Few Showers/Wind</source>
-        <translation>Wenige Schauer/Wind</translation>
+        <translation>wenige Schauer/Wind</translation>
     </message>
     <message>
         <source>Snow/Wind</source>
@@ -258,7 +258,7 @@
     </message>
     <message>
         <source>Light Snow</source>
-        <translation>Leichter Schnee</translation>
+        <translation>etwas Schnee</translation>
     </message>
     <message>
         <source>PM Snow</source>
@@ -266,11 +266,11 @@
     </message>
     <message>
         <source>Few Snow Showers/Wind</source>
-        <translation>Wenige Schneeschauer/Wind</translation>
+        <translation>wenige Schneeschauer/Wind</translation>
     </message>
     <message>
         <source>Light Snow/Wind</source>
-        <translation>Leichter Schnee/Wind</translation>
+        <translation>etwas Schnee/Wind</translation>
     </message>
     <message>
         <source>Wintry Mix</source>
@@ -282,15 +282,15 @@
     </message>
     <message>
         <source>Hvy Rain/Freezing Rain</source>
-        <translation>Sta. Regen/Gefr. Regen</translation>
+        <translation>heftiger/gefr. Regen</translation>
     </message>
     <message>
         <source>AM Light Snow</source>
-        <translation>Vorm. leichter Schnee</translation>
+        <translation>Vorm. etwas Schnee</translation>
     </message>
     <message>
         <source>Rain/Freezing Rain</source>
-        <translation>Regen/Gefr. Regen</translation>
+        <translation>Regen/gefr. Regen</translation>
     </message>
     <message>
         <source>T-Storms/Wind</source>
@@ -330,7 +330,7 @@
     </message>
     <message>
         <source>Heavy Rain</source>
-        <translation>Starker Regen</translation>
+        <translation>heftiger Regen</translation>
     </message>
     <message>
         <source>AM Rain/Ice</source>
@@ -342,11 +342,11 @@
     </message>
     <message>
         <source>AM Light Snow/Wind</source>
-        <translation>Vorm. leichter Schnee/Wind</translation>
+        <translation>Vorm. etwas Schnee/Wind</translation>
     </message>
     <message>
         <source>PM Light Rain/Wind</source>
-        <translation>Nachm. leichter Regen/Wind</translation>
+        <translation>Nachm. etwas Regen/Wind</translation>
     </message>
     <message>
         <source>AM Light Wintry Mix</source>
@@ -354,11 +354,11 @@
     </message>
     <message>
         <source>PM Light Snow/Wind</source>
-        <translation>Nachm. leichter Schnee/Wind</translation>
+        <translation>Nachm. etwas Schnee/Wind</translation>
     </message>
     <message>
         <source>Heavy Rain/Wind</source>
-        <translation>Starker Regen/Wind</translation>
+        <translation>heftiger Regen/Wind</translation>
     </message>
     <message>
         <source>PM Snow Shower</source>
@@ -386,7 +386,7 @@
     </message>
     <message>
         <source>PM Light Snow</source>
-        <translation>Nachm. leichter Schnee</translation>
+        <translation>Nachm. etwas Schnee</translation>
     </message>
     <message>
         <source>AM Drizzle</source>
@@ -394,7 +394,7 @@
     </message>
     <message>
         <source>Strong Storms/Wind</source>
-        <translation>Starke Stürme/Wind</translation>
+        <translation>starke Stürme/Wind</translation>
     </message>
     <message>
         <source>PM Drizzle</source>
@@ -406,7 +406,7 @@
     </message>
     <message>
         <source>AM Light Rain/Wind</source>
-        <translation>Vorm. leichter Regen/Wind</translation>
+        <translation>Vorm. etwas Regen/Wind</translation>
     </message>
     <message>
         <source>AM Rain/Wind</source>
@@ -422,15 +422,15 @@
     </message>
     <message>
         <source>Light Rain Shower</source>
-        <translation>Leichter Regenschauer</translation>
+        <translation>leichte Regenschauer</translation>
     </message>
     <message>
         <source>Light Rain with Thunder</source>
-        <translation>Leichter Regen mit Donner</translation>
+        <translation>etwas Regen mit Donner</translation>
     </message>
     <message>
         <source>Light Drizzle</source>
-        <translation>Leichter Nieselregen</translation>
+        <translation>leichter Nieselregen</translation>
     </message>
     <message>
         <source>Mist</source>
@@ -446,11 +446,11 @@
     </message>
     <message>
         <source>Light Snow Shower</source>
-        <translation>Leichter Schneeschauer</translation>
+        <translation>leichte Schneeschauer</translation>
     </message>
     <message>
         <source>Light Snow Shower/ Windy</source>
-        <translation>Leichter Schneeschauer/Wind</translation>
+        <translation>leichte Schneeschauer/Wind</translation>
     </message>
     <message>
         <source>Clear</source>
@@ -458,7 +458,7 @@
     </message>
     <message>
         <source>A Few Clouds</source>
-        <translation>Wenige Wolken</translation>
+        <translation>wenige Wolken</translation>
     </message>
     <message>
         <source>Fair</source>
@@ -540,11 +540,11 @@
     </message>
     <message>
         <source>[ retrieving weather data ... ]</source>
-        <translation>[ hole Wetterdaten ... ]</translation>
+        <translation>[ hole Wetterdaten... ]</translation>
     </message>
     <message>
         <source>current conditions</source>
-        <translation>Aktuelles Wetter</translation>
+        <translation>Das aktuelle Wetter</translation>
     </message>
     <message>
         <source>Humidity</source>
@@ -552,11 +552,11 @@
     </message>
     <message>
         <source>Pressure</source>
-        <translation>Druck</translation>
+        <translation>Luftdruck</translation>
     </message>
     <message>
         <source>Wind</source>
-        <translation>Windgeschwindigkeit</translation>
+        <translation>Windgeschw.</translation>
     </message>
     <message>
         <source>Visibility</source>
@@ -584,7 +584,7 @@
     </message>
     <message>
         <source>today&apos;s forecast</source>
-        <translation>Vorhersage für heute</translation>
+        <translation>Vorhersage für Heute</translation>
     </message>
     <message>
         <source>tomorrow&apos;s outlook</source>
@@ -634,6 +634,18 @@
         <source>To save, press &apos;i&apos; - to cancel, hit escape</source>
         <translation>Mit &apos;i&apos; speichern; ESCAPE um abzubrechen</translation>
     </message>
+    <message>
+        <source>COLD</source>
+        <translation>kalt</translation>
+    </message>
+    <message>
+        <source>COLDEST</source>
+        <translation>am kältesten</translation>
+    </message>
+    <message>
+        <source>CLOUD TEMPERATURE</source>
+        <translation>Wolkentemperatur</translation>
+    </message>
 </context>
 <context>
     <name>Weather</name>
@@ -651,11 +663,11 @@
     </message>
     <message>
         <source>Use the right arrow key to select unit conversion...</source>
-        <translation>Pfeil-nach-rechts benutzen, um Einheitenkonvertierung zu wählen...</translation>
+        <translation>Mit Pfeil-Rechts das Maßsystem wählen...</translation>
     </message>
     <message>
         <source>Weather Units</source>
-        <translation>Wettereinheiten</translation>
+        <translation>Maßsystem</translation>
     </message>
     <message>
         <source>Location</source>
@@ -675,27 +687,27 @@
     </message>
     <message>
         <source>Use the right arrow key to select your location...</source>
-        <translation>Pfeil-nach-rechts benutzen, um Ort zu wählen...</translation>
+        <translation>Mit Pfeil-Rechts den Ort auswählen...</translation>
     </message>
     <message>
         <source>Use the right arrow key to select the aggressiveness level...</source>
-        <translation>Pfeil-nach-rechts benutzen, um Agressivitäts-Level zu wählen...</translation>
+        <translation>Mit Pfeil-Rechts die Agressivitätsstufe wählen...</translation>
     </message>
     <message>
         <source> 1  High Speed Connection</source>
-        <translation> 1  Schnelle Verbindung</translation>
+        <translation> 1  schnelle Verbindung</translation>
     </message>
     <message>
         <source> 8  Medium Speed Connection</source>
-        <translation> 8  Mittlere Verbindung</translation>
+        <translation> 8  mittlere Verbindung</translation>
     </message>
     <message>
         <source> 15 Low Speed Connection</source>
-        <translation> 15 Langsame Verbindung</translation>
+        <translation> 15 langsame Verbindung</translation>
     </message>
     <message>
         <source>Obtaining initial weather data...</source>
-        <translation>Hole initiale Wetterdaten...</translation>
+        <translation>Hole anfängliche Wetterdaten...</translation>
     </message>
     <message>
         <source>Updating weather data...</source>
@@ -731,35 +743,35 @@
     </message>
     <message>
         <source>Today a high of </source>
-        <translation>Heute ein Hoch mit </translation>
+        <translation>Heute Höchstwerte um </translation>
     </message>
     <message>
         <source> and a low of </source>
-        <translation> und Tiefstwerte um </translation>
+        <translation>°C und Tiefstwerte um </translation>
     </message>
     <message>
         <source>. Currently there is a humidity of </source>
-        <translation>. Zzt. herrscht eine Luftfeuchtigkeit von </translation>
+        <translation>°C. Momentan herrscht eine Luftfeuchtigkeit von </translation>
     </message>
     <message>
         <source>% and the winds are</source>
-        <translation>% und der Wind ist </translation>
+        <translation>% und der Wind </translation>
     </message>
     <message>
         <source> calm.</source>
-        <translation>ruhig. </translation>
+        <translation>ist ruhig. </translation>
     </message>
     <message>
         <source> coming in at </source>
-        <translation> wehen mit </translation>
+        <translation>weht mit </translation>
     </message>
     <message>
         <source> mph from the </source>
-        <translation> MPH von </translation>
+        <translation> mph von </translation>
     </message>
     <message>
         <source> Km/h from the </source>
-        <translation> km/h von  </translation>
+        <translation> km/h von </translation>
     </message>
     <message>
         <source> Visibility will be unlimited for today.</source>
@@ -771,7 +783,7 @@
     </message>
     <message>
         <source> There will be a visibility of </source>
-        <translation> Es wir eine Sicht herrschen von </translation>
+        <translation> Die Sichtweite beträgt </translation>
     </message>
     <message>
         <source> miles.</source>
@@ -781,58 +793,30 @@
         <source> km.</source>
         <translation> km.</translation>
     </message>
-    <message>
-        <source>SUN</source>
-        <translation type="obsolete">SO</translation>
-    </message>
     <message>
         <source>Sunday</source>
         <translation>Sonntag</translation>
     </message>
-    <message>
-        <source>MON</source>
-        <translation type="obsolete">MO</translation>
-    </message>
     <message>
         <source>Monday</source>
         <translation>Montag</translation>
     </message>
-    <message>
-        <source>TUE</source>
-        <translation type="obsolete">DI</translation>
-    </message>
     <message>
         <source>Tuesday</source>
         <translation>Dienstag</translation>
     </message>
-    <message>
-        <source>WED</source>
-        <translation type="obsolete">MI</translation>
-    </message>
     <message>
         <source>Wednesday</source>
         <translation>Mittwoch</translation>
     </message>
-    <message>
-        <source>THU</source>
-        <translation type="obsolete">DO</translation>
-    </message>
     <message>
         <source>Thursday</source>
         <translation>Donnerstag</translation>
     </message>
-    <message>
-        <source>FRI</source>
-        <translation type="obsolete">FR</translation>
-    </message>
     <message>
         <source>Friday</source>
         <translation>Freitag</translation>
     </message>
-    <message>
-        <source>SAT</source>
-        <translation type="obsolete">SA</translation>
-    </message>
     <message>
         <source>Saturday</source>
         <translation>Samstag</translation>
@@ -861,25 +845,13 @@
         <source> (Not All Information Available)</source>
         <translation> (Nicht alle Informationen vorhanden)</translation>
     </message>
-    <message>
-        <source>*** Invalid Area ID Entered *** Use a valid area id.</source>
-        <translation type="obsolete">*** Ungültige Orts-ID eingegeben *** Gültige ID eingeben.</translation>
-    </message>
-    <message>
-        <source>Weather Data Not Available</source>
-        <translation type="obsolete">Wetterdaten nicht verfügbar</translation>
-    </message>
-    <message>
-        <source>!!! Timeout Limit !!! Change aggressiveness level.</source>
-        <translation type="obsolete">!!! Zeitüberschreitung !!! Agressivitäts-Level ändern.</translation>
-    </message>
     <message>
         <source>*** Invalid Area ID or Server Error ***</source>
         <translation>*** Ungültige Orts-ID oder Server-Fehler ***</translation>
     </message>
     <message>
         <source>Imperial (Fahrenheit, in, etc)</source>
-        <translation>Imperial (Fahrenheit, Inch, etc.)</translation>
+        <translation>Britisch (Fahrenheit, Inch, etc.)</translation>
     </message>
     <message>
         <source>Metric (Celsius, kPa, etc)</source>
@@ -903,7 +875,15 @@
     </message>
     <message>
         <source> - PAUSED -</source>
-        <translation> - PAUSIERT -</translation>
+        <translation> - PAUSE -</translation>
+    </message>
+    <message>
+        <source>doppler radar</source>
+        <translation>Dopplerradar</translation>
+    </message>
+    <message>
+        <source>satellite image</source>
+        <translation>Satellitenbild</translation>
     </message>
 </context>
 </TS>
