@@ -634,6 +634,18 @@
         <source>To save, press &apos;i&apos; - to cancel, hit escape</source>
         <translation>保存するには &apos;i&apos;,キャンセルするには Esc を押してください</translation>
     </message>
+    <message>
+        <source>COLD</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>COLDEST</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CLOUD TEMPERATURE</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Weather</name>
@@ -865,5 +877,13 @@
         <source> - PAUSED -</source>
         <translation>- 一時停止 -</translation>
     </message>
+    <message>
+        <source>doppler radar</source>
+        <translation type="unfinished">レーダー画像</translation>
+    </message>
+    <message>
+        <source>satellite image</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
