@@ -769,6 +769,18 @@
         <source>To save, press &apos;i&apos; - to cancel, hit escape</source>
         <translation>Para gravar, prima &apos;i&apos;, para cancelar, use o &apos;escape&apos;</translation>
     </message>
+    <message>
+        <source>COLD</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>COLDEST</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CLOUD TEMPERATURE</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Weather</name>
@@ -1028,5 +1040,13 @@
         <source> - PAUSED -</source>
         <translation>- PARADO -</translation>
     </message>
+    <message>
+        <source>doppler radar</source>
+        <translation type="unfinished">Imagem de Satélite</translation>
+    </message>
+    <message>
+        <source>satellite image</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
