@@ -32,7 +32,7 @@ void runWeather(void);
 
 void setupKeys(void)
 {
-    REG_JUMP("MythWeather", "Weather forcasts", "", runWeather);
+    REG_JUMP("MythWeather", "Weather forecasts", "", runWeather);
 
     REG_KEY("Weather", "PAUSE", "Pause current page", "P");
 }
@@ -52,18 +52,9 @@ void runWeather(void)
 {
     int appCode = 0;
 
-    QTranslator translator(0);
-    translator.load(PREFIX + QString("/share/mythtv/i18n/mythweather_") +
-                    QString(gContext->GetSetting("Language").lower()) +
-                    QString(".qm"), ".");
-
-    qApp->installTranslator(&translator);
-
     Weather weatherDat(QSqlDatabase::database(), appCode, 
                        gContext->GetMainWindow(), "weather");
     weatherDat.exec();
-
-    qApp->removeTranslator(&translator);
 }
 
 int mythplugin_run(void)
@@ -76,19 +67,10 @@ int mythplugin_config(void)
 {
     int appCode = 2;
 
-    QTranslator translator(0);
-    translator.load(PREFIX + QString("/share/mythtv/i18n/mythweather_") +
-                    QString(gContext->GetSetting("Language").lower()) +
-                    QString(".qm"), ".");
-
-    qApp->installTranslator(&translator);
-
     Weather weatherDat(QSqlDatabase::database(), appCode,
                        gContext->GetMainWindow(), "weather");
     weatherDat.exec();
 
-    qApp->removeTranslator(&translator);
-
     return 0;
 }
 
