@@ -47,7 +47,7 @@ Weather::Weather(QSqlDatabase *db, int appCode, MythMainWindow *parent,
     stopProcessing = false;
 
     allowkeys = true;
-   
+    wantAnimated = gContext->GetNumSetting("WeatherWantAnimated", 0);   
     weatherTimeoutInt = gContext->GetNumSetting("WeatherTimeout", 20);
     weatherTimeoutInt *= 1000;
     
@@ -73,9 +73,9 @@ Weather::Weather(QSqlDatabase *db, int appCode, MythMainWindow *parent,
     noACCID = false;
 
     wData = NULL;
+    fullRect = QRect(0, 0, size().width(), size().height());
+    newlocRect = QRect(0, 0, size().width(), size().height());
 
-    fullRect = QRect(0, 0, (int)(800*wmult), (int)(600*hmult));
-    newlocRect = QRect(0, 0, (int)(800*wmult), (int)(600*hmult));
 
     if (debug == true)
         cerr << "MythWeather: Reading InstallPrefix from context.\n";
@@ -2131,13 +2131,35 @@ bool Weather::UpdateData()
         
         if(haveData == false)
         {
-            QString msg = QString("Myth was unable to retrieve your weather data within the "
-                                  "time allowed (%1 seconds).\nPress OK to try again with a larger "
-                                  "timeout value. Press Cancel to abort.")
-                                  .arg(weatherTimeoutInt / 1000);
+            QString msg;
+            if(wantAnimated)
+            {
+                
+                msg = QString(tr("Myth was unable to retrieve your weather data within the "
+                              "time allowed (%1 seconds).\nPress OK to try again with a larger "
+                              "timeout value. Press Cancel to try again without animated radar maps."))
+                              .arg(weatherTimeoutInt / 1000);
+                
+                wantRetry = MythPopupBox::showOkCancelPopup(gContext->GetMainWindow(),
+                                                            "Timeout Reached", msg, true);
+                if(!wantRetry)
+                {
+                    wantAnimated = 0;
+                    wantRetry = true;
+                }
+            }
+            else
+            {
+                msg = QString(tr("Myth was unable to retrieve your weather data within the "
+                              "time allowed (%1 seconds).\nPress OK to try again with a larger "
+                              "timeout value. Press Cancel to abort."))
+                               .arg(weatherTimeoutInt / 1000);
+                
+                wantRetry = MythPopupBox::showOkCancelPopup(gContext->GetMainWindow(),
+                                                            "Timeout Reached", msg, true);
+            }
+            
 
-            wantRetry = MythPopupBox::showOkCancelPopup(gContext->GetMainWindow(), 
-                                                        "Timeout Reached", msg, true);
             if(wantRetry)
                 weatherTimeoutInt += (weatherTimeoutInt / 2);
                                                         
@@ -2326,7 +2348,7 @@ void Weather::setWeatherTypeIcon(QString wt[5])
             if (wt[i].toInt() == wData[j].typeNum)
             {
                 wt[i] = tr(wData[j].typeName);
-                weatherIcon[i] = wData[j].typeIcon;
+                weatherIcon[i] = "weather/" + wData[j].typeIcon;
                 isSet = true;
                 j = 128;
             }
@@ -2335,7 +2357,7 @@ void Weather::setWeatherTypeIcon(QString wt[5])
         if (isSet == false)
         {
             wt[i] = tr("Unknown") + " [" + wt[i] + "]";
-            weatherIcon[i] = "unknown.png";
+            weatherIcon[i] = "weather/unknown.png";
         }
     }
 }
@@ -2347,20 +2369,20 @@ void Weather::setWeatherIcon(QString txtType)
         if (txtType.replace(QRegExp("  "),  "" ) == 
             (wData[j].typeName).replace(QRegExp("  "),  "" ))
         {
-            curIcon = wData[j].typeIcon;
+            curIcon = "weather/" + wData[j].typeIcon;
             description = tr(wData[j].typeName);
             return;
         }
         
         if (txtType.toInt() == wData[j].typeNum)
         {
-            curIcon = wData[j].typeIcon;
+            curIcon = "weather/" + wData[j].typeIcon;
             description = tr(wData[j].typeName);
             return;
         }
     }
     
-    curIcon = "unknown.png";
+    curIcon = "weather/unknown.png";
 }
 
 QString Weather::GetString(QString tag)
@@ -2407,6 +2429,8 @@ float Weather::GetFloat(QString tag)
 
 bool Weather::GetWeatherData()
 {
+    
+    
     QUrl weatherDataURL("http://www.msnbc.com/m/chnk/d/weather_d_src.asp?acid=" + locale);
 
     INETComms *weatherData = new INETComms(weatherDataURL);
@@ -2447,7 +2471,7 @@ bool Weather::GetWeatherData()
     weatherData = NULL;
 
      // try to get some animated radar maps
-     if (GetAnimatedRadarMap())
+     if (wantAnimated && GetAnimatedRadarMap())
          return true;
 
      // could not get animated radar maps so try to find a static map instead
